summaryrefslogtreecommitdiffhomepage
path: root/examples/advanced.c
diff options
context:
space:
mode:
authorTyge Løvset <[email protected]>2020-09-16 09:59:18 +0200
committerTyge Løvset <[email protected]>2020-09-16 09:59:18 +0200
commit47b5b5ce53ed4607bf557e2b53a1286bc8041e94 (patch)
tree71219fd9554c957b4e120d34096318fc11f8fc80 /examples/advanced.c
parentd3d68271e1c4ff0f56d06730f79349197f46850c (diff)
downloadSTC-modified-47b5b5ce53ed4607bf557e2b53a1286bc8041e94.tar.gz
STC-modified-47b5b5ce53ed4607bf557e2b53a1286bc8041e94.zip
Changed earlier declare_<container>(..) macro to typedef_<container>(..)
Diffstat (limited to 'examples/advanced.c')
-rw-r--r--examples/advanced.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/advanced.c b/examples/advanced.c
index 0570ce55..2c736e2d 100644
--- a/examples/advanced.c
+++ b/examples/advanced.c
@@ -50,8 +50,8 @@ Viking viking_fromVw(VikingVw vw) {
Viking vk = {cstr(vw.name), cstr(vw.country)}; return vk;
}
-// Using the full c_cmap() macro to define [Viking -> int] hash map type:
-c_cmap(vk, Viking, int, c_default_destroy, vikingvw_equals, vikingvw_hash,
+// Using the full typedef_cmap() macro to define [Viking -> int] hash map type:
+typedef_cmap(vk, Viking, int, c_default_destroy, vikingvw_equals, vikingvw_hash,
viking_destroy, VikingVw, viking_toVw, viking_fromVw);
// cmap_vk uses vikingvw_hash() for hash value calculations, and vikingvw_equals() for equality test.